function [RSSI] = CalculateRSSI(recObj, SampleTime, FilterCentre, FilterBandwidth, FilterOrder, Plot)
%% Author Information
% Calculate Recieved Signal Strength Indicator from WAV File
%
% George Smart
% Department of Electronic & Electrical Engineering
% University College London
%
% http://www.george-smart.co.uk/
%

%% Take Samples
% Record and convert to array
recordblocking(recObj, SampleTime);
raw_samples = getaudiodata(recObj);

%% Calculate stuff for Graph Scaling!
fVector=[((-recObj.SampleRate+0)/2):(recObj.SampleRate/(recObj.TotalSamples-1)):((recObj.SampleRate-0)/2)];

%% FFT Input Data
raw_fft = fft(raw_samples);
shifted_fft = fftshift(raw_fft);
abs_fft = abs(shifted_fft);

%% Synthesize Filter
BandStart = FilterCentre-(FilterBandwidth/2); % Hz
BandStop = FilterCentre+(FilterBandwidth/2);
DigitalStart = ((BandStart/max(fVector-1))/2)+0.5; % normalised
DigitalStop = ((BandStop/max(fVector-1))/2)+0.5;

% Define a normalised finite impulse response filter
PassBand = fir1 (FilterOrder, [DigitalStart DigitalStop]);
% Determine the filters transfer function, H(e^jw)
PassBand = freqz(PassBand,1,recObj.TotalSamples);
% Find the magnitude of the transfer function
PassBand = abs(PassBand);

FilteredData = abs_fft(:,1) .* PassBand;

%% Graph Y-Scaler
RSSI = max(FilteredData);
Y_Max = RSSI + (RSSI/10);

%% Plot Graphs
if (Plot == true) 
    subplot(3, 1, 1);
    plot(fVector, abs_fft(:,1));
    axis([0 3e3 0 Y_Max]);
    title('Raw FFT');
    xlabel('Frequency/Hz');
    ylabel('Relative Scaled Input Level');

    subplot(3, 1, 2);
    plot(fVector, PassBand, 'r');
    axis([0 3e3 0 1.1]);
    title(sprintf('%d-Order Filter - %d Hz wide at %d Hz', FilterOrder, FilterBandwidth, FilterCentre));
    xlabel('Frequency/Hz');
    ylabel('Filter Gain');

    h3 = subplot(3, 1, 3);
    cla(h3)
    hold on; % Plot RSSI lines over FilteredData
    plot(fVector, FilteredData);
    plot(fVector, ones(size(FilteredData)) .* RSSI, 'g' )
    text(1000, RSSI, ['RSSI: ', num2str(RSSI)]);
    hold off;
    axis([0 3e3 0 Y_Max]);
    title('Filtered Data');
    xlabel('Frequency/Hz');
    ylabel('Filter Output Level');
end
end